#
# spec file for package perl-CBOR-XS
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           perl-CBOR-XS
Version:        1.83
Release:        pm151.2.1
#Upstream: CHECK(Artistic-1.0 or GPL-1.0-or-later)
%define cpan_name CBOR-XS
Summary:        Concise Binary Object Representation (CBOR, RFC7049)
License:        GPL-3.0-only
Group:          Development/Libraries/Perl
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/M/ML/MLEHMANN/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Canary::Stability)
BuildRequires:  perl(Types::Serialiser)
BuildRequires:  perl(common::sense)
Requires:       perl(Types::Serialiser)
Requires:       perl(common::sense)
%{perl_requires}

%description
This module converts Perl data structures to the Concise Binary Object
Representation (CBOR) and vice versa. CBOR is a fast binary serialisation
format that aims to use an (almost) superset of the JSON data model, i.e.
when you can represent something useful in JSON, you should be able to
represent it in CBOR.

In short, CBOR is a faster and quite compact binary alternative to JSON,
with the added ability of supporting serialisation of Perl objects. (JSON
often compresses better than CBOR though, so if you plan to compress the
data later and speed is less important you might want to compare both
formats first).

The primary goal of this module is to be _correct_ and the secondary goal
is to be _fast_. To reach the latter goal it was written in C.

To give you a general idea about speed, with texts in the megabyte range,
'CBOR::XS' usually encodes roughly twice as fast as Storable or JSON::XS
and decodes about 15%-30% faster than those. The shorter the data, the
worse Storable performs in comparison.

Regarding compactness, 'CBOR::XS'-encoded data structures are usually about
20% smaller than the same data encoded as (compact) JSON or Storable.

In addition to the core CBOR data format, this module implements a number
of extensions, to support cyclic and shared data structures (see
'allow_sharing' and 'allow_cycles'), string deduplication (see
'pack_strings') and scalar references (always enabled).

See MAPPING, below, on how CBOR::XS maps perl values to CBOR values and
vice versa.

%prep
%setup -q -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
make %{?_smp_mflags}

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes README
%license COPYING

%changelog
* Wed Dec  9 2020 Tina Müller <timueller+perl@suse.de>
- updated to 1.83
  see /usr/share/doc/packages/perl-CBOR-XS/Changes
  1.83 Tue Dec  8 09:27:06 CET 2020
  - add CBOR::XS::as_map cast function.
* Tue Dec  1 2020 Tina Müller <timueller+perl@suse.de>
- updated to 1.82
  see /usr/share/doc/packages/perl-CBOR-XS/Changes
  TODO: type cast tests.
  TODO: possibly implement https://peteroupc.github.io/CBOR/extended.html, but NaNs are nonportable. rely on libecb?
  TODO: https://github.com/svaarala/cbor-specs/blob/master/cbor-nonutf8-string-tags.rst, but maybe that is overkill?
  1.82 Tue Dec  1 02:47:40 CET 2020
  - add CBOR::XS::as_bool cast function.
  1.81 Mon Nov 30 19:29:33 CET 2020
  - cast functions were broken due to last-minute renaming. thats
    what you get for not having a tessuite.
  - Math::BigInt and Math::BigFloat are pretty broken (again),
    so disable some tests. (try printing the bigfloat
    799999999999999999998E99999999999999999998).
  1.8  Sun Nov 29 22:35:13 CET 2020
  - experimental support for some type casts, as well as embedding
    raw cbor data.
* Thu Dec  6 2018 Stephan Kulow <coolo@suse.com>
- updated to 1.71
  see /usr/share/doc/packages/perl-CBOR-XS/Changes
  1.71 Thu Nov 15 20:52:13 CET 2018
  - work around what smells like a perl bug w.r.t. exceptions
    thrown in callbacks.
  - update libecb.
* Wed Jun 28 2017 coolo@suse.com
- updated to 1.7
  see /usr/share/doc/packages/perl-CBOR-XS/Changes
  1.7  Tue Jun 27 04:02:23 CEST 2017
  - SECURITY FIX: fix two bugs found by american fuzzy lop,
    upgrade is advised if you accept data from untrusted
    sources.
  - an out-of bound sharedref or stringref index could cause an
    out of bounds access - might be exploitable.
  - a decoding error during indefinite array or hash decoding
    could cause an endless loop.
* Thu Dec  8 2016 coolo@suse.com
- updated to 1.6
  see /usr/share/doc/packages/perl-CBOR-XS/Changes
* Thu Jun  2 2016 coolo@suse.com
- initial package 1.5
  * created by cpanspec 1.78.08
